Crate loadsmith_install

Crate loadsmith_install 

Install, remove, and list mod files for the loadsmith mod-manager library.

This is an internal crate of the [loadsmith] workspace. Most consumers should depend on the loadsmith facade crate instead of using this crate directly.

Examples

use loadsmith_install::ConflictStrategy;
use loadsmith_install::install;
use loadsmith_install::uninstall;
use loadsmith_install::extract;
use loadsmith_install::GlobRule;
use loadsmith_install::RouteRule;
use loadsmith_install::InstallRule;
use loadsmith_install::InstallRuleset;

// Each public type and function is available at the crate root.
let strategy = ConflictStrategy::Overwrite;
assert_eq!(format!("{strategy:?}"), "Overwrite");

Structs

GlobRule
A glob-based install rule that maps matching files to a target directory.
InstallRuleset
A borrowed set of install rules used to map and filter package files.
OwnedInstallRuleset
An owned set of install rules with optional exclude glob and default rule.
RouteRule
A route-based install rule that maps files by directory name and file extension.

Enums

ConflictStrategy
Strategy for handling file conflicts during installation.
Error
Errors that can occur during mod installation, extraction, or removal.
InstallRule
A file-mapping rule that can be either a GlobRule or a RouteRule.

Functions

extract
Extract all files from a zip archive into a target directory.
install
Install a package’s files into a game profile directory.
uninstall
Remove all files that belong to an installed package from a profile directory.

Type Aliases

Result
Convenience alias for Error results.