pub enum InstallRule {
Glob(GlobRule),
Route(RouteRule),
}Expand description
A file-mapping rule that can be either a GlobRule or a RouteRule.
Examples
use camino::Utf8Path;
use loadsmith_install::{InstallRule, GlobRule, RouteRule};
let glob: InstallRule = GlobRule::try_from_pattern("*.dll", Utf8Path::new("BepInEx/plugins")).unwrap().into();
let route: InstallRule = RouteRule::new_static("plugins").into();Variants
Glob(GlobRule)
Maps files using a glob pattern.
Route(RouteRule)
Maps files by matching a route (directory name) and file extension.
Implementations
Sourceimpl InstallRule
impl InstallRule
Sourcepub fn matches(&self, path: impl AsRef<Utf8Path>) -> bool
pub fn matches(&self, path: impl AsRef<Utf8Path>) -> bool
Returns true if the path matches this rule by path content or file extension.
Sourcepub fn matches_path(&self, path: impl AsRef<Utf8Path>) -> bool
pub fn matches_path(&self, path: impl AsRef<Utf8Path>) -> bool
Sourcepub fn matches_extension(&self, path: impl AsRef<Utf8Path>) -> bool
pub fn matches_extension(&self, path: impl AsRef<Utf8Path>) -> bool
Sourcepub fn map_file(
&self,
path: impl AsRef<Utf8Path>,
package: &PackageRef,
) -> Option<Utf8PathBuf>
pub fn map_file( &self, path: impl AsRef<Utf8Path>, package: &PackageRef, ) -> Option<Utf8PathBuf>
Maps a file path to its install destination.
Sourcepub fn matches_mapped(&self, path: impl AsRef<Utf8Path>) -> bool
pub fn matches_mapped(&self, path: impl AsRef<Utf8Path>) -> bool
Returns true if the mapped path starts with this rule’s target directory.
Sourcepub fn conflict_strategy(&self) -> ConflictStrategy
pub fn conflict_strategy(&self) -> ConflictStrategy