Install, remove, and list mod files for the loadsmith mod-manager library.
This is an internal crate of the [loadsmith] workspace. Most consumers
should depend on the loadsmith facade crate instead of using this
crate directly.
Examples
use loadsmith_install::ConflictStrategy;
use loadsmith_install::install;
use loadsmith_install::uninstall;
use loadsmith_install::extract;
use loadsmith_install::GlobRule;
use loadsmith_install::RouteRule;
use loadsmith_install::InstallRule;
use loadsmith_install::InstallRuleset;
// Each public type and function is available at the crate root.
let strategy = ConflictStrategy::Overwrite;
assert_eq!(format!("{strategy:?}"), "Overwrite");Structs
- Glob
Rule - A glob-based install rule that maps matching files to a target directory.
- Install
Ruleset - A borrowed set of install rules used to map and filter package files.
- Owned
Install Ruleset - An owned set of install rules with optional exclude glob and default rule.
- Route
Rule - A route-based install rule that maps files by directory name and file extension.
Enums
- Conflict
Strategy - Strategy for handling file conflicts during installation.
- Error
- Errors that can occur during mod installation, extraction, or removal.
- Install
Rule - A file-mapping rule that can be either a
GlobRuleor aRouteRule.
Functions
- extract
- Extract all files from a zip archive into a target directory.
- install
- Install a package’s files into a game profile directory.
- uninstall
- Remove all files that belong to an installed package from a profile directory.