Crate loadsmith_install

Crate loadsmith_install 

Install, remove, and list mod files for the loadsmith mod-manager library.

This is an internal crate of the [loadsmith] workspace. Most consumers should depend on the loadsmith facade crate instead of using this crate directly.

Structs

GlobRule
InstallRuleset
OwnedInstallRuleset
RouteRule

Enums

ConflictStrategy
Error
InstallRule

Functions

extract
install
uninstall

Type Aliases

Result